@@ -12,29 +12,39 @@
 #  License for the specific language governing permissions and limitations
 #  under the License.
 
-import six
+from io import StringIO
 import yaml
 
+from unittest import mock
+
 from cliff.formatters import yaml_format
 from cliff.tests import base
 from cliff.tests import test_columns
 
-import mock
+
+class _toDict:
+    def __init__(self, **kwargs):
+        self._data = kwargs
+
+    def toDict(self):
+        return self._data
+
+
+class _to_Dict:
+    def __init__(self, **kwargs):
+        self._data = kwargs
+
+    def to_dict(self):
+        return self._data
 
 
 class TestYAMLFormatter(base.TestBase):
-
     def test_format_one(self):
         sf = yaml_format.YAMLFormatter()
         c = ('a', 'b', 'c', 'd')
         d = ('A', 'B', 'C', '"escape me"')
-        expected = {
-            'a': 'A',
-            'b': 'B',
-            'c': 'C',
-            'd': '"escape me"'
-        }
-        output = six.StringIO()
+        expected = {'a': 'A', 'b': 'B', 'c': 'C', 'd': '"escape me"'}
+        output = StringIO()
         args = mock.Mock()
         sf.emit_one(c, d, output, args)
         actual = yaml.safe_load(output.getvalue())
@@ -54,7 +64,7 @@ class TestYAMLFormatter(base.TestBase):
         sf.add_argument_group(args)
 
         args.noindent = True
-        output = six.StringIO()
+        output = StringIO()
         sf.emit_one(c, d, output, args)
         value = output.getvalue()
         print(len(value.splitlines()))
@@ -64,17 +74,13 @@ class TestYAMLFormatter(base.TestBase):
     def test_list(self):
         sf = yaml_format.YAMLFormatter()
         c = ('a', 'b', 'c')
-        d = (
-            ('A1', 'B1', 'C1'),
-            ('A2', 'B2', 'C2'),
-            ('A3', 'B3', 'C3')
-        )
+        d = (('A1', 'B1', 'C1'), ('A2', 'B2', 'C2'), ('A3', 'B3', 'C3'))
         expected = [
             {'a': 'A1', 'b': 'B1', 'c': 'C1'},
             {'a': 'A2', 'b': 'B2', 'c': 'C2'},
-            {'a': 'A3', 'b': 'B3', 'c': 'C3'}
+            {'a': 'A3', 'b': 'B3', 'c': 'C3'},
         ]
-        output = six.StringIO()
+        output = StringIO()
         args = mock.Mock()
         sf.add_argument_group(args)
         sf.emit_list(c, d, output, args)
@@ -84,9 +90,7 @@ class TestYAMLFormatter(base.TestBase):
     def test_formattablecolumn_list(self):
         sf = yaml_format.YAMLFormatter()
         c = ('a', 'b', 'c')
-        d = (
-            ('A1', 'B1', test_columns.FauxColumn(['the', 'value'])),
-        )
+        d = (('A1', 'B1', test_columns.FauxColumn(['the', 'value'])),)
         expected = [
             {'a': 'A1', 'b': 'B1', 'c': ['the', 'value']},
         ]
@@ -94,7 +98,43 @@ class TestYAMLFormatter(base.TestBase):
         sf.add_argument_group(args)
 
         args.noindent = True
-        output = six.StringIO()
+        output = StringIO()
+        sf.emit_list(c, d, output, args)
+        actual = yaml.safe_load(output.getvalue())
+        self.assertEqual(expected, actual)
+
+    def test_one_custom_object(self):
+        sf = yaml_format.YAMLFormatter()
+        c = ('a', 'b', 'toDict', 'to_dict')
+        d = ('A', 'B', _toDict(spam="ham"), _to_Dict(ham="eggs"))
+        expected = {
+            'a': 'A',
+            'b': 'B',
+            'toDict': {"spam": "ham"},
+            'to_dict': {"ham": "eggs"},
+        }
+        output = StringIO()
+        args = mock.Mock()
+        sf.emit_one(c, d, output, args)
+        actual = yaml.safe_load(output.getvalue())
+        self.assertEqual(expected, actual)
+
+    def test_list_custom_object(self):
+        sf = yaml_format.YAMLFormatter()
+        c = ('a', 'toDict', 'to_dict')
+        d = (
+            ('A1', _toDict(B=1), _to_Dict(C=1)),
+            ('A2', _toDict(B=2), _to_Dict(C=2)),
+            ('A3', _toDict(B=3), _to_Dict(C=3)),
+        )
+        expected = [
+            {'a': 'A1', 'toDict': {'B': 1}, 'to_dict': {'C': 1}},
+            {'a': 'A2', 'toDict': {'B': 2}, 'to_dict': {'C': 2}},
+            {'a': 'A3', 'toDict': {'B': 3}, 'to_dict': {'C': 3}},
+        ]
+        output = StringIO()
+        args = mock.Mock()
+        sf.add_argument_group(args)
         sf.emit_list(c, d, output, args)
         actual = yaml.safe_load(output.getvalue())
         self.assertEqual(expected, actual)
