@@ -13,18 +13,15 @@
 #  under the License.
 
 import os
-import sys
-
 from unittest import mock
 
-from cliff import utils
 from cliff.tests import base
+from cliff import utils
 
 
 class TestTerminalWidth(base.TestBase):
-
     def test(self):
-        width = utils.terminal_width(sys.stdout)
+        width = utils.terminal_width()
         # Results are specific to the execution environment, so only assert
         # that no error is raised.
         if width is not None:
@@ -34,8 +31,8 @@ class TestTerminalWidth(base.TestBase):
     def test_get_terminal_size(self, mock_os):
         ts = os.terminal_size((10, 5))
         mock_os.get_terminal_size.return_value = ts
-        width = utils.terminal_width(sys.stdout)
+        width = utils.terminal_width()
         self.assertEqual(10, width)
         mock_os.get_terminal_size.side_effect = OSError()
-        width = utils.terminal_width(sys.stdout)
+        width = utils.terminal_width()
         self.assertIs(None, width)
